@@ -1,12 +1,6 @@
-/* LibTomCrypt, modular cryptographic library -- Tom St Denis
- *
- * LibTomCrypt is a library that provides various cryptographic
- * algorithms in a highly modular and flexible manner.
- *
- * The library is free for all purposes without any express
- * guarantee it works.
- */
-#include "tomcrypt.h"
+/* LibTomCrypt, modular cryptographic library -- Tom St Denis */
+/* SPDX-License-Identifier: Unlicense */
+#include "tomcrypt_private.h"
 
 /**
    @file cfb_start.c
@@ -19,7 +13,7 @@
 /**
    Initialize a CFB context
    @param cipher      The index of the cipher desired
-   @param IV          The initial vector
+   @param IV          The initialization vector
    @param key         The secret key
    @param keylen      The length of the secret key (octets)
    @param num_rounds  Number of rounds in the cipher desired (0 for default)
@@ -43,8 +37,9 @@ int cfb_start(int cipher, const unsigned char *IV, const unsigned char *key,
    /* copy data */
    cfb->cipher = cipher;
    cfb->blocklen = cipher_descriptor[cipher].block_length;
-   for (x = 0; x < cfb->blocklen; x++)
+   for (x = 0; x < cfb->blocklen; x++) {
        cfb->IV[x] = IV[x];
+   }
 
    /* init the cipher */
    if ((err = cipher_descriptor[cipher].setup(key, keylen, num_rounds, &cfb->key)) != CRYPT_OK) {
@@ -57,7 +52,3 @@ int cfb_start(int cipher, const unsigned char *IV, const unsigned char *key,
 }
 
 #endif
-
-/* ref:         $Format:%D$ */
-/* git commit:  $Format:%H$ */
-/* commit time: $Format:%ai$ */
